@@ -17,7 +17,10 @@ class Code:
         self._iter_idx = -1
         return self
 
-    def __next__(self):
+    def __next__(self) -> str:
+        if self._iter_idx is None or self._iter_code_lines is None or self._iter_num_code_lines is None:
+            raise Exception("Code iterator not initialized")
+        
         self._iter_idx += 1
         if self._iter_idx < self._iter_num_code_lines:
             return self._iter_code_lines[self._iter_idx]
